@@ -64,8 +64,6 @@ class PostgreSQLUtils:
 
         self.connection = None
         self.cp = ColorPrint()  # 添加彩色打印实例
-        self._sequence_cache = {}  # 序列缓存，避免重复检查
-        self._sequence_cache_timeout = 60  # 缓存超时时间（秒）
         PostgreSQLUtils._initialized = True
 
     def _load_config_from_env(self):
@@ -146,7 +144,8 @@ class PostgreSQLUtils:
                 password=self.password,
                 port=self.port,
             )
-
+            # 连接建立时初始化本连接周期的已重置表集合
+            self._sequence_reset_tables = set()
             return True
         except Exception as e:
             logging.error(f"数据库连接失败: {e}")
@@ -192,7 +191,7 @@ class PostgreSQLUtils:
                 query = f"SELECT setval(%s, %s, %s)"
                 cursor.execute(query, (sequence_name, setval_value, is_called))
                 self.connection.commit()
-                # self.cp.green(f"{table_name}表{primary_key}序列已重置为{setval_value}")
+                # self.cp.green(f"{table_name} 表 {primary_key} 序列已重置为 {setval_value}")
             else:
                 # 尝试使用更通用的序列名查找方式
                 find_sequence_query = """
@@ -237,6 +236,9 @@ class PostgreSQLUtils:
         if self.connection and not self.connection.closed:
             self.connection.close()
             self.connection = None
+        # 断开连接时清空已重置表集合
+        if hasattr(self, '_sequence_reset_tables'):
+            self._sequence_reset_tables.clear()
 
     def find(
         self, sql: str, to_json: bool = False, *args, **kwargs
@@ -307,8 +309,12 @@ class PostgreSQLUtils:
         if not self.connect():
             return False
 
-        # 重置表序列以防止主键冲突
-        self._reset_sequence_for_table(table)
+        # 仅在本连接周期内未重置过该表时重置序列
+        if not hasattr(self, '_sequence_reset_tables'):
+            self._sequence_reset_tables = set()
+        if table not in self._sequence_reset_tables:
+            self._reset_sequence_for_table(table)
+            self._sequence_reset_tables.add(table)
 
         # 处理字典类型的数据
         processed_data = self._process_data_for_insertion(data)
@@ -352,8 +358,12 @@ class PostgreSQLUtils:
         if not self.connect():
             return False
 
-        # 重置表序列以防止主键冲突
-        self._reset_sequence_for_table(table)
+        # 仅在本连接周期内未重置过该表时重置序列
+        if not hasattr(self, '_sequence_reset_tables'):
+            self._sequence_reset_tables = set()
+        if table not in self._sequence_reset_tables:
+            self._reset_sequence_for_table(table)
+            self._sequence_reset_tables.add(table)
 
         # 处理所有数据中的字典类型
         processed_data_list = [
@@ -417,8 +427,12 @@ class PostgreSQLUtils:
         if not self.connect():
             return False
 
-        # 重置表序列以防止主键冲突
-        self._reset_sequence_for_table(table)
+        # 仅在本连接周期内未重置过该表时重置序列
+        if not hasattr(self, '_sequence_reset_tables'):
+            self._sequence_reset_tables = set()
+        if table not in self._sequence_reset_tables:
+            self._reset_sequence_for_table(table)
+            self._sequence_reset_tables.add(table)
 
         # 处理字典类型的数据
         processed_data = self._process_data_for_insertion(data)
